eprllib.ObservationFunctions.centralized — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.ObservationFunctions.centralized

## Centralized Agent Policy

A central agent take the observation of all the agents involve in the environment and concatenate them to create a single observation. After transform the multiple observations in one, this is used in the central policy to select the multiple discrete action, one for each agent.

To avoid parameter repetitions in the central agent observation, only implement an observation parameter in one single agent. For example, if two agents are present in the same thermal zone and both of them has access to the thermal zone mean air temperature, only declares this parameter in one of them.

Classes

`centralized`(obs_fn_config) |